@@ -1,15 +1,18 @@
 glag <-
-function(x, k=1, pad=FALSE, pad.value=NA){
+function(x, k=1, pad=TRUE, pad.value=NA)
+{
   #check arguments:
   if(k < 1) stop("Lag order k cannot be less than 1")
 
-  #zoo-related operations:
+  #zoo-related:
   iszoo.chk <- is.zoo(x)
-  x <- as.zoo(cbind(x))
-  x.n <- NROW(x)
-  x.ncol <- NCOL(x)
+  x <- as.zoo(x)
   x.index <- index(x)
   x <- coredata(x)
+  isvector <- is.vector(x)
+  x <- cbind(x)
+  x.n <- NROW(x)
+  x.ncol <- NCOL(x)
 
   #do the lagging:
   x.nmink <- x.n - k
@@ -18,6 +21,11 @@ function(x, k=1, pad=FALSE, pad.value=NA){
     xlagged <- rbind( matrix(pad.value,k,x.ncol) , xlagged)
   }
 
+  #transform to vector?:
+  if(x.ncol==1 && isvector==TRUE){
+    xlagged <- as.vector(xlagged)
+  }
+
   #if(is.zoo(x)):
   if(iszoo.chk){
     if(pad){
@@ -28,8 +36,5 @@ function(x, k=1, pad=FALSE, pad.value=NA){
   } #end if(iszoo.chk)
 
   #out:
-  if(x.ncol==1){
-    xlagged <- as.vector(xlagged)
-  }
   return(xlagged)
 }
